/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *   Co-authors:
 *      ...
 *
 */

/**
    @file Invader.cc
    @brief Implementation of the Invader class.
*/

#include "Asteroids.h"
#include "Highscore.h"
#include "core/CoreIncludes.h"
#include "core/EventIncludes.h"
#include "core/command/Executor.h"
#include "core/config/ConfigValueIncludes.h"

#include "gamestates/GSLevel.h"
#include "chat/ChatManager.h"

// ! HACK
#include "infos/PlayerInfo.h"

#include "AsteroidsCenterPoint.h"
#include "AsteroidsShip.h"

#include "core/command/ConsoleCommand.h"
#include "worldentities/ExplosionPart.h"

namespace orxonox
{
    RegisterUnloadableClass(Asteroids);

    Asteroids::Asteroids(Context* context) : Deathmatch(context)
    {
        RegisterObject(Asteroids);
        this->numberOfBots_ = 0; //sets number of default bots temporarly to 0
        this->center_ = nullptr;
        bEndGame = false;
        lives = 3;
        point = 0;

        // Pre-set the timer, but don't start it yet.
        this->enemySpawnTimer_.setTimer(5.0, true, createExecutor(createFunctor(&Asteroids::spawnStone, this)));
    }

    //spawnt durch den Timer Asteroiden, denk dran, dass falls ein Asteroid stirbt er in 2 teile geteilt wird
    Asteroids::spawnStone(){
        if(getPlayer() == nullptr){
            return;
        }

        AsteroidsStone* newStone;
        newStone = new AsteroidsStone(this->center_->getContext());
        newStone->addTemplate("asteroidsstone");
        newStone->setAsteroidsPlayer(player);
    }

        void Invader::spawnEnemy()
    {
        if (getPlayer() == nullptr)
            return;

        for (int i = 0; i < (3*log10(static_cast<double>(level)) + 1); i++)
        {
            InvaderEnemy* newPawn;
            if (rand() % 42/(1 + level*level) == 0)
            {
                newPawn = new InvaderEnemyShooter(this->center_->getContext());
                newPawn->addTemplate("enemyinvadershooter");
            }
            else
            {
                newPawn = new InvaderEnemy(this->center_->getContext());
                newPawn->addTemplate("enemyinvader");
            }
            newPawn->setInvaderPlayer(player);
            newPawn->level = level;
            // spawn enemy at random points in front of player.
            newPawn->setPosition(player->getPosition() + Vector3(500.f + 100 * i, 0, float(rand())/RAND_MAX * 400 - 200));
        }
    }

    /**
    @brief
        Destructor. Cleans up, if initialized.
    */
    Asteroids::~Asteroids()
    {
        if (this->isInitialized())
            this->cleanup();
    }

    /**
    @brief
        Cleans up the Gametype by destroying all of the objects in the game - spaceship and asteroids.
    */
    void Asteroids::cleanup()
    {
        if (this->stones_ != nullptr) // Destroy the ball, if present.
        {
            this->stones_->destroy();
            this->stones_ = nullptr;
        }

        // Destroy AsteroidsShip

        if (this->player != nullptr)
        {
            this->player->destroy();
            this->player = nullptr;
        }
    }

    AsteroidsShip* Asteroids::getPlayer()
    {
        if (player == nullptr)
        {
            for (Asteroids* ship : ObjectList<AsteroidsShip>())
                player = ship;
        }
        return player;
    }


    void Asteroids::setCenterpoint(AsteroidsCenterPoint* center)
    {
        this->center_ = center;
    }

    void Asteroids::costLife()
    {
        lives = 0;
    };
    void Asteroids::start()
    {
        if (this->center_ == nullptr) // There needs to be a AsteroidsCenterpoint, i.e. the area the game takes place. If no centerpoint was specified, an error is thrown and the level is exited.
        {
            orxout(internal_error) << "Asteroids: No Centerpoint specified." << endl;
            GSLevel::startMainMenu();
            return;
        }

        // Set variable to temporarily force the player to spawn.
        bool temp = this->bForceSpawn_;
        this->bForceSpawn_ = true;

        // Call start for the parent class.
        Deathmatch::start();

        // Reset the variable.
        this->bForceSpawn_ = temp;
    }

    void Asteroids::addPoints(int numPoints)
    {
        if (!bEndGame)
        {
            point += numPoints;
        }
    }

    void Asteroids::end()
    {
        // DON'T CALL THIS!
        //      Deathmatch::end();
        // It will misteriously crash the game!
        // Instead startMainMenu, this won't crash.
        GSLevel::startMainMenu();
    }
}
