/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *   Co-authors:
 *      ...
 *
 */

/**
    @file Invader.h
    @brief Gametype.
    @ingroup Invader
*/

#ifndef _Asteroids_H__
#define _Asteroids_H__

#include "asteroids/AsteroidsPrereqs.h"
#include "gametypes/Deathmatch.h"
#include "tools/Timer.h"

namespace orxonox
{

    class _AsteroidsExport Asteroids : public Deathmatch
    {
        public:
            Asteroids(Context* context);

            virtual void start() override;
            virtual void end() override;
            virtual void tick(float dt) override;
            virtual void addBots(unsigned int amount) override{} //<! overwrite function in order to bypass the addbots command

            void setCenterpoint(AsteroidsCenterPoint* center);

            int getLives(){return this->lives;}
            int getPoints(){return this->point;}
            
            void costLife();
            void addPoints(int numPoints);

            void spawnStone();

            int lives;
            bool bEndGame;
            
        private:
            void toggleShowLevel(){bShowLevel = !bShowLevel;}
            void cleanup(void); //!< Cleans up the Gametype by destroying the ball and the bats.
            AsteroidsShip* getPlayer();
            WeakPtr<AsteroidsCenterPoint> center_;
            WeakPtr<AsteroidsShip> player;
            WeakPtr<Camera> camera;
            WeakPtr<AsteroidsStones> stones_;

            Timer enemySpawnTimer;
            //Context* context;
            int level;
            int point;
            bool b_combo;

            Timer starttimer_; //!< A timer to delay the start of the game.
    };
}

#endif /* _Invader_H__ */
