/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *   Co-authors:
 *      ...
 *
 */

/**
    @file DodgeRace.h
    @brief Gametype.
    @ingroup DodgeRace
*/

#ifndef _Asteroids_H__
#define _Asteroids_H__


#include "asteroids/AsteroidsPrereqs.h"
#include "gametypes/Deathmatch.h"
#include "worldentities/pawns/SpaceShip.h"
#include "weapons/projectiles/Projectile.h"
#include <math.h>

namespace orxonox
{

    class _AsteroidsExport Asteroids : public SpaceShip
    {
       public:
            Asteroids(Context* context);

            virtual void tick(float dt) override;

            // overwrite for 2d movement
            virtual void moveFrontBack(const Vector2& value) override;
            virtual void moveRightLeft(const Vector2& value) override;
            virtual void moveUpDown(const Vector2& value) override;

            // Starts or stops fireing
            virtual void boost(bool bBoost) override;


            void setCenterpoint(AsteroidsCenterPoint* center)
                       { this->center_ = center; }


            virtual void addBots(unsigned int amount) override{} //<! overwrite function in order to bypass the addbots command

            bool bEndGame;
            bool bShowLevel;
            int lives;
            float angle, radius;
            float speed, damping, posforeward;
            bool isFireing;

            //Nachschauen wie gross das Spielfeld ist!
            float H = 1000;
            float W = 1000;

        protected:
            virtual void death() override;

       private:
            Asteroids* getGame();
            WeakPtr<Asteroids> game;
            WeakPtr<WorldEntity> lastEntity;
            Camera* camera;
            float lastTimeFront, lastTimeLeft, lastTime;
            struct Velocity
            {
                float x;
                float y;
            } velocity, desiredVelocity;
            
    };
}

#endif /* _Asteroids_H__ */
